@@ -5,10 +5,10 @@ use 5.008001;
 use strict;
 use warnings;
 
-our $VERSION = '1.301001_070';
+our $VERSION = '1.301001_071';
 $VERSION = eval $VERSION;    ## no critic (BuiltinFunctions::ProhibitStringyEval)
 
-use Test::Stream '-internal';
+use Test::Stream 1.301001_071 '-internal';
 use Test::Stream::Toolset;
 
 use Test::Stream::Exporter;
